==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/scripts/es.php <==
<?php

return [
    'Names' => [
        'Arab' => 'árabe',
        'Aran' => 'nastaliq',
        'Armn' => 'armenio',
        'Avst' => 'avéstico',
        'Bali' => 'balinés',
        'Batk' => 'batak',
        'Beng' => 'bengalí',
        'Blis' => 'símbolos blis',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmi',
        'Brai' => 'braille',
        'Bugi' => 'buginés',
        'Buhd' => 'buhid',
        'Cans' => 'silabarios aborígenes canadienses unificados',
        'Cari' => 'cario',
        'Cham' => 'cham',
        'Cher' => 'cherokee',
        'Cirt' => 'cirth',
        'Copt' => 'copto',
        'Cprt' => 'chipriota',
        'Cyrl' => 'cirílico',
        'Cyrs' => 'cirílico del antiguo eslavo eclesiástico',
        'Deva' => 'devanagari',
        'Dsrt' => 'deseret',
        'Egyd' => 'egipcio demótico',
        'Egyh' => 'egipcio hierático',
        'Egyp' => 'jeroglíficos egipcios',
        'Ethi' => 'etiópico',
        'Geok' => 'georgiano eclesiástico',
        'Geor' => 'georgiano',
        'Glag' => 'glagolítico',
        'Goth' => 'gótico',
        'Grek' => 'griego',
        'Gujr' => 'guyaratí',
        'Guru' => 'gurmuji',
        'Hanb' => 'han con bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanunoo',
        'Hans' => 'simplificado',
        'Hant' => 'tradicional',
        'Hebr' => 'hebreo',
        'Hira' => 'hiragana',
        'Hmng' => 'pahawh hmong',
        'Hrkt' => 'silabarios japoneses',
        'Hung' => 'húngaro antiguo',
        'Inds' => 'Indio (harappan)',
        'Ital' => 'antigua bastardilla',
        'Jamo' => 'jamo',
        'Java' => 'javanés',
        'Jpan' => 'japonés',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Khar' => 'kharosthi',
        'Khmr' => 'jemer',
        'Knda' => 'canarés',
        'Kore' => 'coreano',
        'Lana' => 'lanna',
        'Laoo' => 'laosiano',
        'Latf' => 'latino fraktur',
        'Latg' => 'latino gaélico',
        'Latn' => 'latino',
        'Lepc' => 'lepcha',
        'Limb' => 'limbu',
        'Lina' => 'lineal A',
        'Linb' => 'lineal B',
        'Lyci' => 'licio',
        'Lydi' => 'lidio',
        'Mand' => 'mandeo',
        'Maya' => 'jeroglíficos mayas',
        'Mero' => 'meroítico',
        'Mlym' => 'malayálam',
        'Mong' => 'mongol',
        'Moon' => 'moon',
        'Mtei' => 'manipuri',
        'Mymr' => 'birmano',
        'Nkoo' => 'n’ko',
        'Ogam' => 'ogham',
        'Olck' => 'ol ciki',
        'Orkh' => 'orkhon',
        'Orya' => 'oriya',
        'Osma' => 'osmaniya',
        'Perm' => 'permiano antiguo',
        'Phag' => 'phags-pa',
        'Phnx' => 'fenicio',
        'Plrd' => 'Pollard Miao',
        'Qaag' => 'zawgyi',
        'Rjng' => 'rejang',
        'Roro' => 'rongo-rongo',
        'Runr' => 'rúnico',
        'Sara' => 'sarati',
        'Saur' => 'saurashtra',
        'Sgnw' => 'SignWriting',
        'Shaw' => 'shaviano',
        'Sinh' => 'cingalés',
        'Sund' => 'sundanés',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'siriaco',
        'Syre' => 'siriaco estrangelo',
        'Syrj' => 'siriaco occidental',
        'Syrn' => 'siriaco oriental',
        'Tagb' => 'tagbanúa',
        'Tale' => 'tai le',
        'Talu' => 'nuevo tai lue',
        'Taml' => 'tamil',
        'Telu' => 'telugu',
        'Teng' => 'tengwar',
        'Tfng' => 'tifinagh',
        'Tglg' => 'tagalo',
        'Thaa' => 'thaana',
        'Thai' => 'tailandés',
        'Tibt' => 'tibetano',
        'Ugar' => 'ugarítico',
        'Vaii' => 'vai',
        'Visp' => 'lenguaje visible',
        'Xpeo' => 'persa antiguo',
        'Xsux' => 'cuneiforme sumerio-acadio',
        'Yiii' => 'yi',
        'Zinh' => 'heredado',
        'Zmth' => 'notación matemática',
        'Zsye' => 'emojis',
        'Zsym' => 'símbolos',
        'Zxxx' => 'no escrito',
        'Zyyy' => 'común',
    ],
];

==> symfony_7.4.2+dfsg.orig.tar.xz: symfony-7.4.2/src/Symfony/Component/Intl/Resources/data/scripts/es.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'ádlam',
        'Arab' => 'árabe',
        'Aran' => 'nastaliq',
        'Armn' => 'armenio',
        'Avst' => 'avéstico',
        'Bali' => 'balinés',
        'Batk' => 'batak',
        'Beng' => 'bengalí',
        'Blis' => 'símbolos blis',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmi',
        'Brai' => 'braille',
        'Bugi' => 'buginés',
        'Buhd' => 'buhid',
        'Cakm' => 'chakma',
        'Cans' => 'silabarios aborígenes canadienses unificados',
        'Cari' => 'cario',
        'Cham' => 'cham',
        'Cher' => 'cheroqui',
        'Cirt' => 'cirth',
        'Copt' => 'copto',
        'Cprt' => 'chipriota',
        'Cyrl' => 'cirílico',
        'Cyrs' => 'cirílico del antiguo eslavo eclesiástico',
        'Deva' => 'devanagari',
        'Dsrt' => 'deseret',
        'Egyd' => 'egipcio demótico',
        'Egyh' => 'egipcio hierático',
        'Egyp' => 'jeroglíficos egipcios',
        'Ethi' => 'etiópico',
        'Geok' => 'georgiano eclesiástico',
        'Geor' => 'georgiano',
        'Glag' => 'glagolítico',
        'Goth' => 'gótico',
        'Grek' => 'griego',
        'Gujr' => 'guyaratí',
        'Guru' => 'gurmuji',
        'Hanb' => 'han con bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanunoo',
        'Hans' => 'simplificado',
        'Hant' => 'tradicional',
        'Hebr' => 'hebreo',
        'Hira' => 'hiragana',
        'Hmng' => 'pahawh hmong',
        'Hrkt' => 'silabarios japoneses',
        'Hung' => 'húngaro antiguo',
        'Inds' => 'Indio (harappan)',
        'Ital' => 'antigua bastardilla',
        'Jamo' => 'jamo',
        'Java' => 'javanés',
        'Jpan' => 'japonés',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Khar' => 'kharosthi',
        'Khmr' => 'jemer',
        'Knda' => 'canarés',
        'Kore' => 'coreano',
        'Lana' => 'lanna',
        'Laoo' => 'laosiano',
        'Latf' => 'latino fraktur',
        'Latg' => 'latino gaélico',
        'Latn' => 'latino',
        'Lepc' => 'lepcha',
        'Limb' => 'limbu',
        'Lina' => 'lineal A',
        'Linb' => 'lineal B',
        'Lyci' => 'licio',
        'Lydi' => 'lidio',
        'Mand' => 'mandeo',
        'Maya' => 'jeroglíficos mayas',
        'Mero' => 'meroítico',
        'Mlym' => 'malayálam',
        'Mong' => 'mongol',
        'Moon' => 'moon',
        'Mtei' => 'meitei',
        'Mymr' => 'birmano',
        'Nkoo' => 'n’ko',
        'Ogam' => 'ogham',
        'Olck' => 'ol chiki',
        'Orkh' => 'orkhon',
        'Orya' => 'oriya',
        'Osma' => 'osmaniya',
        'Perm' => 'permiano antiguo',
        'Phag' => 'phags-pa',
        'Phnx' => 'fenicio',
        'Plrd' => 'Pollard Miao',
        'Qaag' => 'zawgyi',
        'Rjng' => 'rejang',
        'Rohg' => 'hanifi',
        'Roro' => 'rongo-rongo',
        'Runr' => 'rúnico',
        'Sara' => 'sarati',
        'Saur' => 'saurashtra',
        'Sgnw' => 'SignWriting',
        'Shaw' => 'shaviano',
        'Sinh' => 'cingalés',
        'Sund' => 'sundanés',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'siriaco',
        'Syre' => 'siriaco estrangelo',
        'Syrj' => 'siriaco occidental',
        'Syrn' => 'siriaco oriental',
        'Tagb' => 'tagbanúa',
        'Tale' => 'tai le',
        'Talu' => 'nuevo tai lue',
        'Taml' => 'tamil',
        'Telu' => 'telugu',
        'Teng' => 'tengwar',
        'Tfng' => 'tifinagh',
        'Tglg' => 'tagalo',
        'Thaa' => 'thaana',
        'Thai' => 'tailandés',
        'Tibt' => 'tibetano',
        'Ugar' => 'ugarítico',
        'Vaii' => 'vai',
        'Visp' => 'lenguaje visible',
        'Xpeo' => 'persa antiguo',
        'Xsux' => 'cuneiforme sumerio-acadio',
        'Yiii' => 'yi',
        'Zinh' => 'heredado',
        'Zmth' => 'notación matemática',
        'Zsye' => 'emojis',
        'Zsym' => 'símbolos',
        'Zxxx' => 'no escrito',
        'Zyyy' => 'común',
    ],
];
